@@ -4,8 +4,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef AKONADI_COLLECTIONCOLORATTRIBUTE_H
-#define AKONADI_COLLECTIONCOLORATTRIBUTE_H
+#pragma once
 
 #include "akonadicore_export.h"
 
@@ -46,4 +45,3 @@ private:
 
 } // namespace Akonadi
 
-#endif
