@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SPECIALCOLLECTIONSDISCOVERYJOB_H
-#define AKONADI_SPECIALCOLLECTIONSDISCOVERYJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "collection.h"
@@ -14,7 +13,6 @@
 
 namespace Akonadi
 {
-
 class SpecialCollectionsDiscoveryJobPrivate;
 
 /**
@@ -27,13 +25,12 @@ class SpecialCollectionsDiscoveryJobPrivate;
  *
  * @author David Faure <faure@kde.org>
  * @since 4.11
-*/
+ */
 class AKONADICORE_EXPORT SpecialCollectionsDiscoveryJob : public KCompositeJob
 {
     Q_OBJECT
 
 public:
-
     /**
      * Destroys the special collections request job.
      */
@@ -54,11 +51,10 @@ protected:
     void slotResult(KJob *job) override;
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     SpecialCollectionsDiscoveryJobPrivate *const d;
-    //@endcond
+    /// @endcond
 };
 
 } // namespace Akonadi
 
-#endif // AKONADI_SPECIALCOLLECTIONSDISCOVERYJOB_H
